metadata(version="0.6.0")

# Originally written by Paul Sokolovsky.

require("ffilib")
require("errno")
require("stat")

package("os")
